==> node-globby_11.0.2+~cs16.20.37.orig-run-parallel.tar.gz: run-parallel-1.1.10/test/error.js <==
var parallel = require('../')
var test = require('tape')

test('functions that return errors (array)', function (t) {
  t.plan(3)

  var tasks = [
    function (cb) {
      t.pass('cb 1')
      cb(new Error('oops'))
    },
    function (cb) {
      setTimeout(function () {
        t.pass('cb 2')
        cb(null, 2)
      }, 100)
    }
  ]

  parallel(tasks, function (err) {
    t.ok(err instanceof Error)
  })
})

test('functions that return errors (object)', function (t) {
  t.plan(3)

  var tasks = {
    one: function (cb) {
      t.pass('cb 1')
      cb(new Error('oops'))
    },
    two: function (cb) {
      setTimeout(function () {
        t.pass('cb 2')
        cb(null, 2)
      }, 100)
    }
  }

  parallel(tasks, function (err) {
    t.ok(err instanceof Error)
  })
})

test('functions that return errors (object) w/ partial results', function (t) {
  t.plan(4)

  var tasks = {
    one: function (cb) {
      t.pass('cb 1')
      cb(null, 1)
    },
    two: function (cb) {
      setTimeout(function () {
        t.pass('cb 2')
        cb(new Error('oops'))
      }, 100)
    }
  }

  parallel(tasks, function (err, results) {
    t.ok(err instanceof Error)
    t.deepEqual(results, { one: 1, two: undefined })
  })
})

test('array of functions that produce multiple errors', function (t) {
  var tasks = [
    function (cb) {
      cb(new Error('a'))
    },
    function (cb) {
      cb(new Error('b'))
    }
  ]
  parallel(tasks, function (err) {
    t.ok(err.message === 'a', 'only observes the first error')
    t.end()
  })
})

==> node-globby_13.1.3+~cs16.25.40.orig-run-parallel.tar.gz: run-parallel-1.2.0/test/error.js <==
const parallel = require('../')
const test = require('tape')

test('functions that return errors (array)', function (t) {
  t.plan(3)

  const tasks = [
    function (cb) {
      t.pass('cb 1')
      cb(new Error('oops'))
    },
    function (cb) {
      setTimeout(function () {
        t.pass('cb 2')
        cb(null, 2)
      }, 100)
    }
  ]

  parallel(tasks, function (err) {
    t.ok(err instanceof Error)
  })
})

test('functions that return errors (object)', function (t) {
  t.plan(3)

  const tasks = {
    one: function (cb) {
      t.pass('cb 1')
      cb(new Error('oops'))
    },
    two: function (cb) {
      setTimeout(function () {
        t.pass('cb 2')
        cb(null, 2)
      }, 100)
    }
  }

  parallel(tasks, function (err) {
    t.ok(err instanceof Error)
  })
})

test('functions that return errors (object) w/ partial results', function (t) {
  t.plan(4)

  const tasks = {
    one: function (cb) {
      t.pass('cb 1')
      cb(null, 1)
    },
    two: function (cb) {
      setTimeout(function () {
        t.pass('cb 2')
        cb(new Error('oops'))
      }, 100)
    }
  }

  parallel(tasks, function (err, results) {
    t.ok(err instanceof Error)
    t.deepEqual(results, { one: 1, two: undefined })
  })
})

test('array of functions that produce multiple errors', function (t) {
  const tasks = [
    function (cb) {
      cb(new Error('a'))
    },
    function (cb) {
      cb(new Error('b'))
    }
  ]
  parallel(tasks, function (err) {
    t.ok(err.message === 'a', 'only observes the first error')
    t.end()
  })
})
